@@ -1,10 +1,19 @@
+#  Apache License Version 2.0
+#
+#  Copyright (c) 2021., Redis Labs Modules
+#  All rights reserved.
+#
+
 import argparse
 import logging
+import os
 import sys
 
 import toml
 
 from redisbench_admin import __version__
+from redisbench_admin.compare.args import create_compare_arguments
+from redisbench_admin.compare.compare import compare_command_logic
 from redisbench_admin.export.args import create_export_arguments
 from redisbench_admin.export.export import export_command_logic
 from redisbench_admin.extract.args import create_extract_arguments
@@ -13,6 +22,15 @@ from redisbench_admin.run_local.args import create_run_local_arguments
 from redisbench_admin.run_local.run_local import run_local_command_logic
 from redisbench_admin.run_remote.args import create_run_remote_arguments
 from redisbench_admin.run_remote.run_remote import run_remote_command_logic
+from redisbench_admin.watchdog.args import create_watchdog_arguments
+from redisbench_admin.watchdog.watchdog import watchdog_command_logic
+
+
+LOG_LEVEL = logging.INFO
+if os.getenv("VERBOSE", "1") == "0":
+    LOG_LEVEL = logging.WARN
+LOG_FORMAT = "%(asctime)s %(levelname)-4s %(message)s"
+LOG_DATEFMT = "%Y-%m-%d %H:%M:%S"
 
 
 def populate_with_poetry_data():
@@ -30,14 +48,6 @@ def populate_with_poetry_data():
     return project_name, project_description, project_version
 
 
-# logging settings
-logging.basicConfig(
-    format="%(asctime)s %(levelname)-4s %(message)s",
-    level=logging.INFO,
-    datefmt="%Y-%m-%d %H:%M:%S",
-)
-
-
 def main():
     if len(sys.argv) < 2:
         print(
@@ -58,6 +68,9 @@ def main():
     parser.add_argument(
         "--local-dir", type=str, default="./", help="local dir to use as storage"
     )
+    parser.add_argument(
+        "--logname", type=str, default=None, help="logname to write the logs to"
+    )
 
     if requested_tool == "run-remote":
         parser = create_run_remote_arguments(parser)
@@ -67,6 +80,10 @@ def main():
         parser = create_extract_arguments(parser)
     elif requested_tool == "export":
         parser = create_export_arguments(parser)
+    elif requested_tool == "compare":
+        parser = create_compare_arguments(parser)
+    elif requested_tool == "watchdog":
+        parser = create_watchdog_arguments(parser)
     elif requested_tool == "--version":
         print_version(project_name, project_version)
         sys.exit(0)
@@ -74,20 +91,49 @@ def main():
         print_help(project_name, project_version)
         sys.exit(0)
     else:
-        valid_tool_options = ["run-local", "run-remote", "export", "extract"]
+        valid_tool_options = [
+            "compare",
+            "run-local",
+            "run-remote",
+            "export",
+            "extract",
+            "watchdog",
+        ]
         print_invalid_tool_option(requested_tool, valid_tool_options)
         sys.exit(1)
 
     argv = sys.argv[2:]
     args = parser.parse_args(args=argv)
+
+    if args.logname is not None:
+        print("Writting log to {}".format(args.logname))
+        logging.basicConfig(
+            filename=args.logname,
+            filemode="a",
+            format=LOG_FORMAT,
+            datefmt=LOG_DATEFMT,
+            level=LOG_LEVEL,
+        )
+    else:
+        # logging settings
+        logging.basicConfig(
+            format=LOG_FORMAT,
+            level=LOG_LEVEL,
+            datefmt=LOG_DATEFMT,
+        )
+
     if requested_tool == "run-local":
-        run_local_command_logic(args)
+        run_local_command_logic(args, project_name, project_version)
     if requested_tool == "run-remote":
-        run_remote_command_logic(args)
+        run_remote_command_logic(args, project_name, project_version)
     if requested_tool == "export":
-        export_command_logic(args)
+        export_command_logic(args, project_name, project_version)
     if requested_tool == "extract":
-        extract_command_logic(args)
+        extract_command_logic(args, project_name, project_version)
+    if requested_tool == "watchdog":
+        watchdog_command_logic(args, project_name, project_version)
+    if requested_tool == "compare":
+        compare_command_logic(args, project_name, project_version)
 
 
 def print_invalid_tool_option(requested_tool, valid_tool_options):
