@@ -1,19 +1,40 @@
+#  Apache License Version 2.0
+#
+#  Copyright (c) 2021., Redis Labs Modules
+#  All rights reserved.
+#
 import os
 import socket
 
 # environment variables
-PERFORMANCE_RTS_AUTH = os.getenv("PERFORMANCE_RTS_AUTH", None)
-PERFORMANCE_RTS_HOST = os.getenv("PERFORMANCE_RTS_HOST", 6379)
-PERFORMANCE_RTS_PORT = os.getenv("PERFORMANCE_RTS_PORT", None)
-TERRAFORM_BIN_PATH = os.getenv("TERRAFORM_BIN_PATH", "terraform")
+from redisbench_admin.utils.remote import (
+    TERRAFORM_BIN_PATH,
+    PERFORMANCE_RTS_HOST,
+    PERFORMANCE_RTS_PORT,
+    PERFORMANCE_RTS_AUTH,
+    PERFORMANCE_RTS_PUSH,
+)
+
+
+DEFAULT_TRIGGERING_ENV = socket.gethostname()
+TRIGGERING_ENV = os.getenv("TRIGGERING_ENV", DEFAULT_TRIGGERING_ENV)
+ENV = os.getenv("ENV", "oss-standalone,oss-cluster")
 
 
 def create_run_remote_arguments(parser):
-    parser.add_argument("--module_path", type=str, required=True)
+    parser.add_argument("--module_path", type=str, required=False)
+    parser.add_argument(
+        "--dbdir_folder",
+        type=str,
+        required=False,
+        help="If specified the entire contents of the folder are copied to the redis dir.",
+    )
     parser.add_argument(
         "--allowed-tools",
         type=str,
-        default="redis-benchmark,redisgraph-benchmark-go,ycsb,tsbs_run_queries_redistimeseries,tsbs_load_redistimeseries",
+        default="redis-benchmark,redisgraph-benchmark-go,ycsb,"
+        + "tsbs_run_queries_redistimeseries,tsbs_load_redistimeseries,"
+        + "aibench_run_inference_redisai_vision",
         help="comma separated list of allowed tools for this module. By default all the supported are allowed.",
     )
     parser.add_argument(
@@ -34,7 +55,7 @@ def create_run_remote_arguments(parser):
         "You can use `--required-module` more than once",
     )
     parser.add_argument("--github_branch", type=str, default=None, nargs="?", const="")
-    parser.add_argument("--triggering_env", type=str, default=socket.gethostname())
+    parser.add_argument("--triggering_env", type=str, default=TRIGGERING_ENV)
     parser.add_argument("--terraform_bin_path", type=str, default=TERRAFORM_BIN_PATH)
     parser.add_argument("--setup_name_sufix", type=str, default="")
     parser.add_argument(
@@ -50,12 +71,18 @@ def create_run_remote_arguments(parser):
         help="uploads the result files and configuration file to public "
         "'ci.benchmarks.redislabs' bucket. Proper credentials are required",
     )
-    parser.add_argument("--redistimesies_host", type=str, default=PERFORMANCE_RTS_HOST)
-    parser.add_argument("--redistimesies_port", type=int, default=PERFORMANCE_RTS_PORT)
-    parser.add_argument("--redistimesies_pass", type=str, default=PERFORMANCE_RTS_AUTH)
+    parser.add_argument(
+        "--redistimeseries_host", type=str, default=PERFORMANCE_RTS_HOST
+    )
+    parser.add_argument(
+        "--redistimeseries_port", type=int, default=PERFORMANCE_RTS_PORT
+    )
+    parser.add_argument(
+        "--redistimeseries_pass", type=str, default=PERFORMANCE_RTS_AUTH
+    )
     parser.add_argument(
         "--push_results_redistimeseries",
-        default=False,
+        default=PERFORMANCE_RTS_PUSH,
         action="store_true",
         help="uploads the results to RedisTimeSeries. Proper credentials are required",
     )
@@ -65,4 +92,10 @@ def create_run_remote_arguments(parser):
         action="store_true",
         help="skip environment variables check",
     )
+    parser.add_argument(
+        "--allowed-envs",
+        type=str,
+        default=ENV,
+        help="Comma delimited allowed setups: 'oss-standalone','oss-cluster'",
+    )
     return parser
