@@ -1,3 +1,9 @@
+#  Apache License Version 2.0
+#
+#  Copyright (c) 2021., Redis Labs Modules
+#  All rights reserved.
+#
+
 import logging
 import os
 import pathlib
@@ -38,9 +44,35 @@ def parse_exporter_timemetric(metric_path: str, results_dict: dict):
 def prepare_benchmark_definitions(args):
     benchmark_definitions = {}
     defaults_filename, files = get_testfiles_to_process(args)
+
+    (
+        default_kpis,
+        default_metrics,
+        exporter_timemetric_path,
+        default_specs,
+        clusterconfig,
+    ) = get_defaults(defaults_filename)
+    for usecase_filename in files:
+        with open(usecase_filename, "r") as stream:
+            benchmark_config, test_name = get_final_benchmark_config(
+                default_kpis, stream, usecase_filename
+            )
+            benchmark_definitions[test_name] = benchmark_config
+    return (
+        benchmark_definitions,
+        default_metrics,
+        exporter_timemetric_path,
+        default_specs,
+        clusterconfig,
+    )
+
+
+def get_defaults(defaults_filename):
     default_metrics = []
     exporter_timemetric_path = None
     default_kpis = None
+    default_specs = None
+    cluster_config = None
     if os.path.exists(defaults_filename):
         with open(defaults_filename, "r") as stream:
             logging.info(
@@ -50,6 +82,8 @@ def prepare_benchmark_definitions(args):
                 default_kpis,
                 default_metrics,
                 exporter_timemetric_path,
+                default_specs,
+                cluster_config,
             ) = process_default_yaml_properties_file(
                 default_kpis,
                 default_metrics,
@@ -57,18 +91,25 @@ def prepare_benchmark_definitions(args):
                 exporter_timemetric_path,
                 stream,
             )
-    for usecase_filename in files:
-        with open(usecase_filename, "r") as stream:
-            os.path.dirname(os.path.abspath(usecase_filename))
-            benchmark_config = yaml.safe_load(stream)
-            kpis_keyname = "kpis"
-            if default_kpis is not None:
-                merge_default_and_specific_properties_dict_type(
-                    benchmark_config, default_kpis, kpis_keyname, usecase_filename
-                )
-            test_name = benchmark_config["name"]
-            benchmark_definitions[test_name] = benchmark_config
-    return benchmark_definitions, default_metrics, exporter_timemetric_path
+    return (
+        default_kpis,
+        default_metrics,
+        exporter_timemetric_path,
+        default_specs,
+        cluster_config,
+    )
+
+
+def get_final_benchmark_config(default_kpis, stream, usecase_filename):
+    os.path.dirname(os.path.abspath(usecase_filename))
+    benchmark_config = yaml.safe_load(stream)
+    kpis_keyname = "kpis"
+    if default_kpis is not None:
+        merge_default_and_specific_properties_dict_type(
+            benchmark_config, default_kpis, kpis_keyname, usecase_filename
+        )
+    test_name = benchmark_config["name"]
+    return benchmark_config, test_name
 
 
 def merge_default_and_specific_properties_dict_type(
@@ -117,8 +158,9 @@ def merge_default_and_specific_properties_dict_type(
                 )
 
 
-def extract_redis_configuration_parameters(benchmark_config, dbconfig_keyname):
+def extract_redis_dbconfig_parameters(benchmark_config, dbconfig_keyname):
     redis_configuration_parameters = {}
+    dataset_load_timeout_secs = 120
     if dbconfig_keyname in benchmark_config:
         for k in benchmark_config[dbconfig_keyname]:
             if "configuration-parameters" in k:
@@ -126,14 +168,18 @@ def extract_redis_configuration_parameters(benchmark_config, dbconfig_keyname):
                 for item in cp:
                     for k, v in item.items():
                         redis_configuration_parameters[k] = v
+            if "dataset_load_timeout_secs" in k:
+                dataset_load_timeout_secs = k["dataset_load_timeout_secs"]
 
-    return redis_configuration_parameters
+    return redis_configuration_parameters, dataset_load_timeout_secs
 
 
 def process_default_yaml_properties_file(
     default_kpis, default_metrics, defaults_filename, exporter_timemetric_path, stream
 ):
     default_config = yaml.safe_load(stream)
+    default_specs = None
+    cluster_config = None
     if "exporter" in default_config:
         default_metrics = parse_exporter_metrics_definition(default_config["exporter"])
         if len(default_metrics) > 0:
@@ -160,7 +206,25 @@ def process_default_yaml_properties_file(
             )
         )
         default_kpis = default_config["kpis"]
-    return default_kpis, default_metrics, exporter_timemetric_path
+    if "spec" in default_config:
+        logging.info(
+            "Loading default setup SPECs from file: {}".format(defaults_filename)
+        )
+        default_specs = default_config["spec"]
+    if "clusterconfig" in default_config:
+        logging.info(
+            "Loading cluster-config default steps from file: {}".format(
+                defaults_filename
+            )
+        )
+        cluster_config = default_config["clusterconfig"]
+    return (
+        default_kpis,
+        default_metrics,
+        exporter_timemetric_path,
+        default_specs,
+        cluster_config,
+    )
 
 
 def extract_benchmark_tool_settings(benchmark_config):
@@ -221,8 +285,8 @@ def get_testfiles_to_process(args):
             )
         )
     else:
-        logging.info("Running specific benchmark in file: {}".format(args.test))
-        files = [args.test]
+        files = args.test.split(",")
+        logging.info("Running specific benchmark in file: {}".format(files))
     return defaults_filename, files
 
 
