@@ -1,10 +1,15 @@
+#  Apache License Version 2.0
+#
+#  Copyright (c) 2021., Redis Labs Modules
+#  All rights reserved.
+#
+
 import configparser
 import logging
 import os
 import sys
 import tempfile
 
-import boto3
 import git
 import paramiko
 import pysftp
@@ -13,9 +18,21 @@ import redistimeseries.client as client
 from git import Repo
 from jsonpath_ng import parse
 from python_terraform import Terraform
-from tqdm import tqdm
 
 from redisbench_admin.utils.local import check_dataset_local_requirements
+from redisbench_admin.utils.utils import (
+    get_ts_metric_name,
+    EC2_REGION,
+    EC2_SECRET_KEY,
+    EC2_ACCESS_KEY,
+)
+
+# environment variables
+PERFORMANCE_RTS_PUSH = bool(os.getenv("PUSH_RTS", False))
+PERFORMANCE_RTS_AUTH = os.getenv("PERFORMANCE_RTS_AUTH", None)
+PERFORMANCE_RTS_HOST = os.getenv("PERFORMANCE_RTS_HOST", "localhost")
+PERFORMANCE_RTS_PORT = os.getenv("PERFORMANCE_RTS_PORT", 6379)
+TERRAFORM_BIN_PATH = os.getenv("TERRAFORM_BIN_PATH", "terraform")
 
 
 def get_git_root(path):
@@ -119,10 +136,18 @@ def check_dataset_remote_requirements(
     private_key,
     remote_dataset_file,
     dirname,
+    number_primaries,
+    is_cluster,
 ):
     res = True
     dataset, fullpath, tmppath = check_dataset_local_requirements(
-        benchmark_config, ".", dirname
+        benchmark_config,
+        ".",
+        dirname,
+        "./datasets",
+        "dbconfig",
+        number_primaries,
+        is_cluster,
     )
     if dataset is not None:
         logging.info(
@@ -339,24 +364,6 @@ def validate_result_expectations(
     return result
 
 
-def upload_artifacts_to_s3(
-    artifacts, s3_bucket_name, s3_bucket_path, acl="public-read"
-):
-    logging.info("Uploading results to s3")
-    s3 = boto3.resource("s3")
-    bucket = s3.Bucket(s3_bucket_name)
-    progress = tqdm(unit="files", total=len(artifacts))
-    for artifact in artifacts:
-        object_key = "{bucket_path}{filename}".format(
-            bucket_path=s3_bucket_path, filename=artifact
-        )
-        bucket.upload_file(artifact, object_key)
-        object_acl = s3.ObjectAcl(s3_bucket_name, object_key)
-        object_acl.put(ACL=acl)
-        progress.update()
-    progress.close()
-
-
 def check_and_fix_pem_str(ec2_private_pem: str):
     pem_str = ec2_private_pem.replace("-----BEGIN RSA PRIVATE KEY-----", "")
     pem_str = pem_str.replace("-----END RSA PRIVATE KEY-----", "")
@@ -422,18 +429,7 @@ def push_data_to_redistimeseries(rts: client, branch_time_series_dict: dict):
     datapoint_inserts = 0
     if rts is not None:
         for timeseries_name, time_series in branch_time_series_dict.items():
-            try:
-                logging.info(
-                    "Creating timeseries named {} with labels {}".format(
-                        timeseries_name, time_series["labels"]
-                    )
-                )
-                rts.create(timeseries_name, labels=time_series["labels"])
-            except redis.exceptions.ResponseError:
-                logging.warning(
-                    "Timeseries named {} already exists".format(timeseries_name)
-                )
-                pass
+            exporter_create_ts(rts, time_series, timeseries_name)
             for timestamp, value in time_series["data"].items():
                 try:
                     rts.add(
@@ -454,6 +450,19 @@ def push_data_to_redistimeseries(rts: client, branch_time_series_dict: dict):
     return datapoint_errors, datapoint_inserts
 
 
+def exporter_create_ts(rts, time_series, timeseries_name):
+    try:
+        logging.info(
+            "Creating timeseries named {} with labels {}".format(
+                timeseries_name, time_series["labels"]
+            )
+        )
+        rts.create(timeseries_name, labels=time_series["labels"])
+    except redis.exceptions.ResponseError:
+        logging.warning("Timeseries named {} already exists".format(timeseries_name))
+        pass
+
+
 def extract_redisgraph_version_from_resultdict(results_dict: dict):
     version = None
     if "DBSpecificConfigs" in results_dict:
@@ -492,19 +501,15 @@ def extract_perversion_timeseries_from_results(
                 version_tags["version"] = project_version
                 version_tags["test_name"] = str(test_name)
                 version_tags["metric"] = str(metric_name)
-
-                ts_name = (
-                    "ci.benchmarks.redislabs/by.version/"
-                    "{triggering_env}/{github_org}/{github_repo}/"
-                    "{test_name}/{deployment_type}/{version}/{metric}".format(
-                        version=project_version,
-                        github_org=tf_github_org,
-                        github_repo=tf_github_repo,
-                        deployment_type=deployment_type,
-                        test_name=test_name,
-                        triggering_env=tf_triggering_env,
-                        metric=metric_name,
-                    )
+                ts_name = get_ts_metric_name(
+                    "by.version",
+                    project_version,
+                    tf_github_org,
+                    tf_github_repo,
+                    deployment_type,
+                    test_name,
+                    tf_triggering_env,
+                    metric_name,
                 )
 
                 branch_time_series_dict[ts_name] = {
@@ -547,70 +552,75 @@ def extract_perbranch_timeseries_from_results(
 ):
     branch_time_series_dict = {}
     for jsonpath in metrics:
-        jsonpath_expr = parse(jsonpath)
-        metric_name = jsonpath[2:]
-        find_res = jsonpath_expr.find(results_dict)
-        if find_res is not None and len(find_res) > 0:
-            metric_value = float(find_res[0].value)
-
-            branch_tags = get_project_ts_tags(
-                tf_github_org, tf_github_repo, deployment_type, tf_triggering_env
+        try:
+            jsonpath_expr = parse(jsonpath)
+        except Exception:
+            pass
+        finally:
+            metric_name = jsonpath[2:]
+            ts_name = get_ts_metric_name(
+                "by.branch",
+                tf_github_branch,
+                tf_github_org,
+                tf_github_repo,
+                deployment_type,
+                test_name,
+                tf_triggering_env,
+                metric_name,
             )
-            branch_tags["branch"] = str(tf_github_branch)
-            branch_tags["test_name"] = str(test_name)
-            branch_tags["metric"] = str(metric_name)
-            ts_name = (
-                "ci.benchmarks.redislabs/by.branch/"
-                "{triggering_env}/{github_org}/{github_repo}/"
-                "{test_name}/{deployment_type}/{branch}/{metric}".format(
-                    branch=str(tf_github_branch),
-                    github_org=tf_github_org,
-                    github_repo=tf_github_repo,
-                    deployment_type=deployment_type,
-                    test_name=test_name,
-                    triggering_env=tf_triggering_env,
-                    metric=metric_name,
+            find_res = jsonpath_expr.find(results_dict)
+            if find_res is not None and len(find_res) > 0:
+                metric_value = float(find_res[0].value)
+
+                branch_tags = get_project_ts_tags(
+                    tf_github_org, tf_github_repo, deployment_type, tf_triggering_env
                 )
-            )
+                branch_tags["branch"] = str(tf_github_branch)
+                branch_tags["test_name"] = str(test_name)
+                branch_tags["metric"] = str(metric_name)
 
-            branch_time_series_dict[ts_name] = {
-                "labels": branch_tags.copy(),
-                "data": {datapoints_timestamp: metric_value},
-            }
-        else:
-            logging.warning(
-                "Unable to find metric path {} in {}".format(jsonpath, results_dict)
-            )
+                branch_time_series_dict[ts_name] = {
+                    "labels": branch_tags.copy(),
+                    "data": {datapoints_timestamp: metric_value},
+                }
+            else:
+                logging.warning(
+                    "Unable to find metric path {} in {}".format(jsonpath, results_dict)
+                )
     return True, branch_time_series_dict
 
 
 def get_overall_dashboard_keynames(tf_github_org, tf_github_repo, tf_triggering_env):
-    testcases_setname = (
+    prefix = (
         "ci.benchmarks.redislabs/"
-        "{triggering_env}/{github_org}/{github_repo}:testcases".format(
+        + "{triggering_env}/{github_org}/{github_repo}".format(
             triggering_env=tf_triggering_env,
             github_org=tf_github_org,
             github_repo=tf_github_repo,
         )
     )
-    tsname_project_total_success = (
-        "ci.benchmarks.redislabs/"
-        "{triggering_env}/{github_org}/{github_repo}:total_success".format(
-            triggering_env=tf_triggering_env,
-            github_org=tf_github_org,
-            github_repo=tf_github_repo,
-        )
+    testcases_setname = "{}:testcases".format(prefix)
+    tsname_project_total_success = "{}:total_success".format(
+        prefix,
     )
-    tsname_project_total_failures = (
-        "ci.benchmarks.redislabs/"
-        "{triggering_env}/{github_org}/{github_repo}:total_failures".format(
-            triggering_env=tf_triggering_env,
-            github_org=tf_github_org,
-            github_repo=tf_github_repo,
-        )
+    tsname_project_total_failures = "{}:total_failures".format(
+        prefix,
     )
     return (
+        prefix,
         testcases_setname,
         tsname_project_total_failures,
         tsname_project_total_success,
     )
+
+
+def check_ec2_env():
+    if EC2_ACCESS_KEY is None or EC2_ACCESS_KEY == "":
+        logging.error("missing required AWS_ACCESS_KEY_ID env variable")
+        exit(1)
+    if EC2_REGION is None or EC2_REGION == "":
+        logging.error("missing required AWS_DEFAULT_REGION env variable")
+        exit(1)
+    if EC2_SECRET_KEY is None or EC2_SECRET_KEY == "":
+        logging.error("missing required AWS_SECRET_ACCESS_KEY env variable")
+        exit(1)
